clc; clear all; close all; 

set(0,'DefaultAxesFontSize',18);
set(0,'DefaultTextFontSize',18);

tlim = 1800.009/60;            % max time plotted-slow-rerun (minutes)
slip_lim = 0.2;                % max slip plotted-fast-rerun
dt = 100;                      % plot every dt steps
Vo = 1e-6; L = 16.75e-6;       % reference velocity and characteristic slip distance to compute \theta

data1 = importdata('../input/slow_slip_fo_0.57_L_2.5d-6_a_0.01_b_0.019_Vo_1d-7/H001');
t = data1(:,1)/60;             % time in minutes 
del = data1(:,3)*1e3;          % slip in mm
V = data1(:,4);                % slip rate in m/s
tau = data1(:,5)/1e6;          % shear stress in MPa
Pop = data1(:,8)/1e6;          % pore pressure in MPa
Seff = data1(:,6)/1e6;         % effective normal stress in MPa
psi = data1(:,7);              % ln(V_o*theta/L)
theta = (L/Vo)*exp(psi);       % state variable in s
omega = (V./Vo).*exp(psi);     % V*theta/L (how far from steady state?)
f = tau./Seff;                 % friction coefficient

t_8 = t;
Pop_8 = Pop;
del_8 = del;
V_8 = V;
theta_8 = theta;
f_8 = f;
omega_8 = omega;

data2 = importdata('../input/slow_slip_fo_0.57_L_2.5d-6_a_0.01_b_0.019_Vo_1d-9/H001');
t = data2(:,1)/60;             % time in minutes 
del = data2(:,3)*1e3;          % slip in mm
V = data2(:,4);                % slip rate in m/s
tau = data2(:,5)/1e6;          % shear stress in MPa
Pop = data2(:,8)/1e6;          % pore pressure in MPa
Seff = data2(:,6)/1e6;         % effective normal stress in MPa
psi = data2(:,7);              % ln(V_o*theta/L)
theta = (L/Vo)*exp(psi);       % state variable in s
omega = (V./Vo).*exp(psi);     % V*theta/L (how far from steady state?)
f = tau./Seff;                 % friction coefficient

t_9 = t;
Pop_9 = Pop;
del_9 = del;
V_9 = V;
theta_9 = theta;
f_9 = f;
omega_9 = omega; 

data3 = importdata('../input/slow_slip_fo_0.57_L_2.5d-6_a_0.01_b_0.011_Vo_1d-7/H001');
t_base = data3(:,1)/60;             % time in minutes 
Pop_base = data3(:,8)/1e6;          % pore pressure in MPa

t_8 = t_8-27*ones(size(t_8));
t_9 = t_9-27*ones(size(t_9));
t_base = t_base-27*ones(size(t_base));

ha2 = tight_subplot(4,1,[0 0.1 0.1 0],[.1 .05],[.2 .2]);
fig2 = figure(1);
set(fig2,'Position',[350 350 350 450*4/3]); 

axes(ha2(1));
plot(t_base(1:dt:end),Pop_base(1:dt:end),'-','Linewidth',2,'color',[0 0.4470 0.7410]); 
xlim([-27 3])
set(gca,'xtick',[-27 -21 -15 -9 -3 3]);
ylim([0 10])
ylabel('p [MPa]')
ax = gca;
set(gca,'FontName','Avenir','XMinorTick','on','YMinorTick','on');
set(gca,'LineWidth',1);
set(gca,'Xticklabel',[])

axes(ha2(2));
plot(t_8(1:dt:end),del_8(1:dt:end),'--','Linewidth',2,'color',[0 0.4470 0.7410]); hold on 
plot(t_9(1:dt:end),del_9(1:dt:end),'-','Linewidth',2,'color',[0 0.4470 0.7410]); hold off
xlim([-27 3])
set(gca,'xtick',[-27 -21 -15 -9 -3 3]);
ylim([0 slip_lim])
ylabel('Slip [mm]')
ax = gca;
ax.YAxisLocation = 'right';
set(gca,'FontName','Avenir','XMinorTick','on','YMinorTick','on');
set(gca,'LineWidth',1);
set(gca,'Xticklabel',[])

axes(ha2(3));
semilogy(t_8(1:dt:end),V_8(1:dt:end),'--','Linewidth',2,'color',[0 0.4470 0.7410]); hold on 
semilogy(t_9(1:dt:end),V_9(1:dt:end),'-','Linewidth',2,'color',[0 0.4470 0.7410]); hold off
xlim([-27 3])
set(gca,'xtick',[-27 -21 -15 -9 -3 3]);
ylim([1e-12 1e2]);
set(gca,'ytick',[1e-20 1e-10 1e0]);
ylabel('V [m/s]')
set(gca,'FontName','Avenir','XMinorTick','on','YMinorTick','on');
set(gca,'LineWidth',1);
set(gca,'Xticklabel',[])

axes(ha2(4));

semilogy([0 tlim],[1 1],'k--','Linewidth',1); hold on;
semilogy(t_8(1:dt:end),omega_8(1:dt:end),'--','Linewidth',2,'Color',[0 0.4470 0.7410]); hold on 
semilogy(t_9(1:dt:end),omega_9(1:dt:end),'-','Linewidth',2,'Color',[0 0.4470 0.7410]); hold off
xlim([-27 3])
set(gca,'xtick',[-27 -21 -15 -9 -3 3]);
ylim([1e-3 1e3]);
set(gca,'ytick',[1e-3 1e0 1e3]);
ylabel('V\theta/D_{RS}')
xlabel('Time [min]')
ax = gca;
ax.YAxisLocation = 'right';
set(gca,'FontName','Avenir','XMinorTick','on','YMinorTick','on');
set(gca,'LineWidth',1);

fig3 = figure(2);
set(fig3,'Position',[750 550 290 200]);
plot(del_8(1:dt:end),f_8(1:dt:end),'--','Linewidth',2,'color',[0 0.4470 0.7410]); hold on 
plot(del_9(1:dt:end),f_9(1:dt:end),'-','Linewidth',2,'color',[0 0.4470 0.7410]); hold off
xlim([0 0.2])
ylim([0.35 0.75]);
set(gca,'ytick',[0.4 0.5 0.6 0.7]);
ylabel('f')
xlabel('Slip [mm]')
ax = gca;
ax.YAxisLocation = 'left';
set(gca,'FontName','Avenir','XMinorTick','on','YMinorTick','on');
set(gca,'LineWidth',1);

